package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.EnterprisePhotoMapper;
import com.ruoyi.system.domain.EnterprisePhoto;
import com.ruoyi.system.service.IEnterprisePhotoService;

/**
 * 企业文件信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-02-20
 */
@Service
public class EnterprisePhotoServiceImpl implements IEnterprisePhotoService 
{
    @Autowired
    private EnterprisePhotoMapper enterprisePhotoMapper;

    /**
     * 查询企业文件信息
     * 
     * @param id 企业文件信息主键
     * @return 企业文件信息
     */
    @Override
    public EnterprisePhoto selectEnterprisePhotoById(Long id)
    {
        return enterprisePhotoMapper.selectEnterprisePhotoById(id);
    }

    /**
     * 查询企业文件信息列表
     * 
     * @param enterprisePhoto 企业文件信息
     * @return 企业文件信息
     */
    @Override
    public List<EnterprisePhoto> selectEnterprisePhotoList(EnterprisePhoto enterprisePhoto)
    {
        return enterprisePhotoMapper.selectEnterprisePhotoList(enterprisePhoto);
    }

    /**
     * 新增企业文件信息
     * 
     * @param enterprisePhoto 企业文件信息
     * @return 结果
     */
    @Override
    public int insertEnterprisePhoto(EnterprisePhoto enterprisePhoto)
    {
        return enterprisePhotoMapper.insertEnterprisePhoto(enterprisePhoto);
    }

    /**
     * 修改企业文件信息
     * 
     * @param enterprisePhoto 企业文件信息
     * @return 结果
     */
    @Override
    public int updateEnterprisePhoto(EnterprisePhoto enterprisePhoto)
    {
        return enterprisePhotoMapper.updateEnterprisePhoto(enterprisePhoto);
    }

    /**
     * 批量删除企业文件信息
     * 
     * @param ids 需要删除的企业文件信息主键
     * @return 结果
     */
    @Override
    public int deleteEnterprisePhotoByIds(Long[] ids)
    {
        return enterprisePhotoMapper.deleteEnterprisePhotoByIds(ids);
    }

    /**
     * 删除企业文件信息信息
     * 
     * @param id 企业文件信息主键
     * @return 结果
     */
    @Override
    public int deleteEnterprisePhotoById(Long id)
    {
        return enterprisePhotoMapper.deleteEnterprisePhotoById(id);
    }
}
